==> olena-2.0.tar.gz: olena-2.0/milena/tests/global_vars1.cc <==
// Copyright (C) 2008, 2009 EPITA Research and Development Laboratory (LRDE)
//
// This file is part of Olena.
//
// Olena is free software: you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free
// Software Foundation, version 2 of the License.
//
// Olena is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Olena.  If not, see <http://www.gnu.org/licenses/>.
//
// As a special exception, you may use this file as part of a free
// software project without restriction.  Specifically, if other files
// instantiate templates or use macros or inline functions from this
// file, or you compile this file and link it with other files to produce
// an executable, this file does not by itself cause the resulting
// executable to be covered by the GNU General Public License.  This
// exception does not however invalidate any other reasons why the
// executable file might be covered by the GNU General Public License.

#include <mln/all.hh>

int f1();
int f2();

int main ()
{
  {
    int b1 = 10;

    mln::border::thickness = b1;
    int b2 = f1();

    mln_assertion(b1 == b2);
  }

  {
    mln::border::thickness = 4;
    f2();

    mln_assertion(mln::border::thickness == 2);
  }
}

==> olena-2.1.tar.gz: olena-2.1/milena/tests/global_vars1.cc <==
// Copyright (C) 2008, 2009, 2011 EPITA Research and Development
// Laboratory (LRDE)
//
// This file is part of Olena.
//
// Olena is free software: you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free
// Software Foundation, version 2 of the License.
//
// Olena is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Olena.  If not, see <http://www.gnu.org/licenses/>.
//
// As a special exception, you may use this file as part of a free
// software project without restriction.  Specifically, if other files
// instantiate templates or use macros or inline functions from this
// file, or you compile this file and link it with other files to produce
// an executable, this file does not by itself cause the resulting
// executable to be covered by the GNU General Public License.  This
// exception does not however invalidate any other reasons why the
// executable file might be covered by the GNU General Public License.

# undef MLN_WO_GLOBAL_VARS
#include <mln/all.hh>

int f1();
int f2();

int main ()
{
  {
    int b1 = 10;

    mln::border::thickness = b1;
    int b2 = f1();

    // Checking that both files share the same symbol.
    mln_assertion(b1 == b2);
  }

  {
    mln::border::thickness = 4;
    f2();

    // Checking that both files share the same symbol.
    mln_assertion(mln::border::thickness == 2);
  }
}
